using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace WindowsGame1
{
    class GameObject
    {
        public Texture2D sprite;
        public Vector2 position;
        public float rotation;
        public Vector2 center;
        public Vector2 velocity;
        public bool alive;
        public Game1 game;

        public enum Team
        {
            none,
            friendly,
            enemy
        }

        public Team team;

        public GameObject(Texture2D loadedTexture, Game1 igame)
        {
            rotation = 0.0f;
            position = Vector2.Zero;

            sprite = loadedTexture;
            center = new Vector2(sprite.Width / 2, sprite.Height / 2);
            velocity = Vector2.Zero;
            alive = true;

            game = igame;
            team = Team.none;
        }

        public virtual void CollideWith(GameObject other)
        {

        }

        public bool ImportantCollision(GameObject other) {
            if (team == Team.none || other.team == Team.none) return false;
            if (team == other.team) return false;
            return true;
        }

        public virtual void Update(GameTime time)
        {
            if (!alive) return;

            position += velocity * (float)time.ElapsedGameTime.TotalSeconds;

            if (!game.viewportRect.Contains(new Point((int)position.X, (int)position.Y)))
            {
                alive = false;
            }
        }

        public virtual void Draw(SpriteBatch batch)
        {
            batch.Draw(sprite, position, null, Color.White, rotation, center, 1, SpriteEffects.None, 0);
        }

        public virtual Rectangle GetBounds()
        {
            Rectangle r;
            r.X = (int)(position.X - center.X);
            r.Y = (int)(position.Y - center.Y);
            r.Width = sprite.Width;
            r.Height = sprite.Height;
            return r;
        }
    }
}
